import { ProjectConfiguration } from '../../config/workspace-json-project-json';
import { NxJsonConfiguration } from '../../config/nx-json';
import { ProjectGraphExternalNode } from '../../config/project-graph';
import { ConfigurationSourceMaps } from './project-configuration-utils';
import { RemotePlugin } from '../plugins/internal-api';
/**
 * Walks the workspace directory to create the `projectFileMap`, `ProjectConfigurations` and `allWorkspaceFiles`
 * @throws
 * @param workspaceRoot
 * @param nxJson
 */
export declare function retrieveWorkspaceFiles(workspaceRoot: string, projectRootMap: Record<string, string>): Promise<{
    allWorkspaceFiles: import("../../config/project-graph").FileData[];
    fileMap: {
        projectFileMap: ProjectFiles;
        nonProjectFiles: import("../../native").FileData[];
    };
    rustReferences: import("../../native").NxWorkspaceFilesExternals;
}>;
/**
 * Walk through the workspace and return `ProjectConfigurations`. Only use this if the projectFileMap is not needed.
 *
 * @param workspaceRoot
 * @param nxJson
 */
export declare function retrieveProjectConfigurations(workspaceRoot: string, nxJson: NxJsonConfiguration): Promise<RetrievedGraphNodes>;
export declare function retrieveProjectConfigurationsWithAngularProjects(workspaceRoot: string, nxJson: NxJsonConfiguration): Promise<RetrievedGraphNodes>;
export type RetrievedGraphNodes = {
    externalNodes: Record<string, ProjectGraphExternalNode>;
    projects: Record<string, ProjectConfiguration>;
    sourceMaps: ConfigurationSourceMaps;
    projectRootMap: Record<string, string>;
};
export declare function retrieveProjectConfigurationPaths(root: string, plugins: PluginGlobsOnly): string[];
export declare function retrieveProjectConfigurationsWithoutPluginInference(root: string): Promise<Record<string, ProjectConfiguration>>;
export declare function createProjectConfigurations(workspaceRoot: string, nxJson: NxJsonConfiguration, configFiles: string[], plugins: RemotePlugin[]): Promise<RetrievedGraphNodes>;
type PluginGlobsOnly = Array<{
    createNodes?: readonly [string, ...unknown[]];
}>;
export declare function configurationGlobs(plugins: PluginGlobsOnly): string[];
export {};
